#!/bin/ksh

ECHO="/bin/echo"

$ECHO "   "
$ECHO "Install WebSphere Commerce 5.4.0.2 Fixpack"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "   "


# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <wc_home> <was_home> <wc_application_home> <wc_edition> <wc_dbtype>"
   $ECHO "where <wc_home> is the directory where the IBM WebSphere Commerce Server(WC) is installed"
   $ECHO "where <was_home> is the directory where the IBM WebSphere Application Server(WAS) is installed"
   $ECHO "and <wc_application_home> is the directory where your Application is installed in the installedApps directory"
   $ECHO "Example: ./install_was.sh /opt/WebSphere/CommerceServer /opt/WebSphere/AppServer WC_Enterprise_App_[instance].ear Business db2"
}


# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WAS_HOME ] && val=2 && \
      [ -d $WAS_HOME/installedApps/$WC_APPLICATION_HOME ] && val=3 && \
      [ -d $WC_HOME ]
   then
#   	$ECHO "---- Components path check passed -----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "Invalid WAS_HOME directory."
	      ;;
	   2) $ECHO "Invalid WC_APPLICATION_HOME directory."
	      ;;
           3) $ECHO "Invalid WC_HOME directory."
              ;;
	esac
   fi

   return $FALSE
}


# checks if required files exist.
check_files() {
local val=1

   if [ -f $WAS_HOME/java/jre/bin/java ] && val=2 && \
      [ -f ./$JARFILENAME ] && val=3 && \
      [ -f ./$DELTA_JAR ] && val=4 && \
      [ -f $WC_FP5402_DIR/WCfixpack5402_wc_SUN.log ] && val=5 && \
      [ -f $WAS_HOME/properties/com/ibm/websphere/product.xml ] 
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $WAS_HOME/java/jre/bin/java"
	      ;;
	   2) $ECHO "The following file does not exist: $JARFILENAME"
	      ;;
	   3) $ECHO "The following file does not exist: $DELTA_JAR"
	      ;;
           4) $ECHO "The following file does not exist: $WC_FP5402_DIR/WCfixpack5402_wc_SUN.log"
              $ECHO "Please execute the install_wc.sh script first."
              ;;
           5) $ECHO "The following file does not exist: $WAS_HOME/properties/com/ibm/websphere/product.xml"
              ;;
	esac
   fi

   return $FALSE;
}

# verify version files.
verify_version_files() {
local val=1
    if [ -f $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd ] && val=2 && \
       [ -f $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml ]
    then
         $ECHO "---- Verify version files passed ----"
         return $TRUE
         
    else
         $ECHO "---- Please correct following error: ----"

         case $val in
             1) $ECHO "The following file does not exist: $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd"
                 ;;
             2) $ECHO "The following file does not exist: $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml"
                 ;;
         esac
    fi
    return $FALSE;
}

# copy version files
copy_version_files() {

$ECHO "Copying version.xml files"
$ECHO "Copying version.xml files" >> $LOGFILENAME 2>&1
$ECHO "cp $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.xml" >> $LOGFILENAME 2>&1
cp $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.xml >> $LOGFILENAME 2>&1
$ECHO "cp $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.dtd" >> $LOGFILENAME 2>&1
cp $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.dtd >> $LOGFILENAME 2>&1
}

check_dbtype() {
if [[ $WC_DBTYPE != "db2" && $WC_DBTYPE != "oracle" ]]
then
        $ECHO "Incorrect Database type - Exiting"
        exit 0
fi
}

check_edition() {
if [[ $WC_EDITION != "Business" && $WC_EDITION != "Pro" ]]
then
        $ECHO "Incorrect Edition - Exiting"
        exit 0
fi
}

copy_edition_files() {

if [ $WC_EDITION = "Pro" ]; then
$ECHO "main - Copy Pro Edition files"
$ECHO "copying Pro Edition files" >> $LOGFILENAME 2>&1

$ECHO "cp $WC_HOME/service/fixpack/5402/36042/pro/web/tools/adminconsole/UserAdminList.jsp $WAS_HOME/installedApps/$WC_APPLICATION_HOME/wctools.war/tools/adminconsole/UserAdminList.jsp" >> $LOGFILENAME 2>&1
cp $WC_HOME/service/fixpack/5402/36042/pro/web/tools/adminconsole/UserAdminList.jsp $WAS_HOME/installedApps/$WC_APPLICATION_HOME/wctools.war/tools/adminconsole/UserAdminList.jsp >> $LOGFILENAME 2>&1
fi

if [ $WC_EDITION = "Business" ]; then
$ECHO "main - Copy Business Edition files"
$ECHO "copying Business Edition files" >> $LOGFILENAME 2>&1

$ECHO "cp $WC_HOME/service/fixpack/5402/36042/advanced/web/tools/adminconsole/UserAdminList.jsp $WAS_HOME/installedApps/$WC_APPLICATION_HOME/wctools.war/tools/adminconsole/UserAdminList.jsp >> $LOGFILENAME 2>&1"
cp $WC_HOME/service/fixpack/5402/36042/advanced/web/tools/adminconsole/UserAdminList.jsp $WAS_HOME/installedApps/$WC_APPLICATION_HOME/wctools.war/tools/adminconsole/UserAdminList.jsp >> $LOGFILENAME 2>&1
fi

}


copy_dbtype_files() {
if [ $WC_DBTYPE = "db2" ]; then
	$ECHO "main - Copy DB2 database files"
	$ECHO "copying DB2 files" >> $LOGFILENAME 2>&1

cp $WC_HOME/wc.ear/WCSActrlEjbGroup-ejb.jar $WAS_HOME/installedApps/$WC_APPLICATION_HOME/WCSActrlEjbGroup-ejb.jar >> $LOGFILENAME 2>&1
cp $WC_HOME/wc.ear/WCSOptoolsUser-ejb.jar $WAS_HOME/installedApps/$WC_APPLICATION_HOME/WCSOptoolsUser-ejb.jar >> $LOGFILENAME 2>&1
fi

if [ $WC_DBTYPE = "oracle" ]; then
	$ECHO "main - Copy Oracle database files"
	$ECHO "copying Oracle files" >> $LOGFILENAME 2>&1
cp $WC_HOME/lib/oracle/WCSActrlEjbGroup-ejb.jar $WAS_HOME/installedApps/$WC_APPLICATION_HOME/WCSActrlEjbGroup-ejb.jar >> $LOGFILENAME 2>&1
cp $WC_HOME/lib/oracle/WCSOptoolsUser-ejb.jar $WAS_HOME/installedApps/$WC_APPLICATION_HOME/WCSOptoolsUser-ejb.jar >> $LOGFILENAME 2>&1
fi

}


# make service directories
make_service_dir() {

   if [ -d $WC_SERVICE_DIR ]; then
   	if [ -d $WC_FIXPACK_DIR ]; then
	   if [ -d $WC_FP5402_DIR ]; then
	      return
	   else
	      mkdir $WC_FP5402_DIR
	   fi
	else
	   mkdir $WC_FIXPACK_DIR
	   mkdir $WC_FP5402_DIR
	fi
   else
      mkdir $WC_SERVICE_DIR
      mkdir $WC_FIXPACK_DIR
      mkdir $WC_FP5402_DIR
   fi
}

# beginning of script.
#clear

TRUE=0
FALSE=1

#ensure correct number of arguments provided.
if [ $# -ne 5 ]; then
   print_usage
   exit 0
else
   WC_HOME=$1
   WAS_HOME=$2
   WC_APPLICATION_HOME=$3
   WC_EDITION=$4
   WC_DBTYPE=$5
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi


WC_SERVICE_DIR="$WC_HOME/service"
WC_FIXPACK_DIR="$WC_HOME/service/fixpack"
WC_FP5402_DIR="$WC_HOME/service/fixpack/5402"

JARFILENAME="WCfixpack5402_was_SUN.jar"
BACKUPJARFILENAME="$WC_FP5402_DIR/$WC_APPLICATION_HOME"_backup.jar
LOGFILENAME="$WC_FP5402_DIR/$WC_APPLICATION_HOME".log
DELTA_JAR="Delta.jar"

# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi

# check version files.
if verify_version_files; then
   $ECHO "main - check version files PASSED."
else
   $ECHO "main - check version files FAILED."
   exit 0
fi

# make service directories
make_service_dir
$ECHO "main - service directories exist/created."

# copy version files
copy_version_files
$ECHO "main - copied version files."

# Install WebSphere Commerce 5.4.0.2 Fixpack, SUN
$ECHO "main - Installing Fixpack."

$ECHO "main - Checking Edition"
check_edition

$ECHO "main - Checking Database"
check_dbtype

$WAS_HOME/java/jre/bin/java -jar $JARFILENAME -TargetDir $WAS_HOME/installedApps/$WC_APPLICATION_HOME -backupJar $BACKUPJARFILENAME -log $LOGFILENAME -SkipVer

status=$?

if [ $status = 8 ]; then
   $ECHO "exiting install due to user intervention"
   exit 0
fi

$ECHO "main - Copy Edition files"
copy_edition_files

$ECHO "main - Copy Database files"
copy_dbtype_files

$ECHO "main - installing fixpack complete."
$ECHO "Please review the installation guide for any additional instructions."

exit 0
