#!/bin/ksh

ECHO="/bin/echo"

$ECHO "   "
$ECHO "Install WebSphere Commerce Version 5.4.0.2 Fixpack"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "   "

# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <wc_home> <was_home> <wc_edition>"
   $ECHO "Example: ./install_wc.sh /opt/WebSphere/CommerceServer /opt/WebSphere/AppServer Business"
}


# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WC_HOME ] && val=2 && [ -d $WAS_HOME ]
   then
#   	$ECHO "---- Components path check passed -----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "Invalid WC_HOME directory."
	      ;;
	   2) $ECHO "Invalid WAS_HOME directory."
	      ;;
	esac
   fi

   return $FALSE
}


# checks if required files exist.
check_files() {
local val=1

   if [ -f $WAS_HOME/java/jre/bin/java ] && val=2 && \
      [ -f ./$JARFILENAME ] && val=3 && \
      [ -f ./$DELTA_JAR ] && val=4 && \
      [ -f $WAS_HOME/properties/com/ibm/websphere/product.xml ] && val=5 && \
      [ -f $WC_HOME/xml/product.xml ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $WAS_HOME/java/jre/bin/java"
	      ;;
	   2) $ECHO "The following file does not exist: $JARFILENAME"
              ;;
	   3) $ECHO "The following file does not exist: $DELTA_JAR"
	      ;;
           4) $ECHO "The following file does not exist: $WAS_HOME/properties/com/ibm/websphere/product.xml"
              ;;
           5) $ECHO "The following file does not exist: $WC_HOME/xml/product.xml"
              ;;
	esac
   fi

   return $FALSE;
}

check_edition() {
if [[ $WC_EDITION != "Business" && $WC_EDITION != "Pro" ]]
then
	$ECHO "Incorrect Edition - Exiting"
	exit 0
fi
}

copy_edition_files() {

CURR_DIR=$PWD

if [ $WC_EDITION = "Pro" ]; then
$ECHO "main - Pro Edition"
$ECHO "copying Pro Edition files" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
$ECHO "cp $WC_HOME/service/fixpack/5402/36042/pro/web/tools/adminconsole/UserAdminList.jsp $WC_HOME/wc.ear/wctools.war/tools/adminconsole/UserAdminList.jsp" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp $WC_HOME/service/fixpack/5402/36042/pro/web/tools/adminconsole/UserAdminList.jsp $WC_HOME/wc.ear/wctools.war/tools/adminconsole/UserAdminList.jsp >> $WC_FP5402_DIR/$LOGFILENAME 2>&1

$ECHO "cp $WC_FP5402_DIR/xml/version.Pro.xml $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp $WC_HOME/service/fixpack/5402/xml/version.Pro.xml $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
$ECHO "cp $WC_HOME/service/fixpack/5402/xml/version.dtd $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp $WC_HOME/service/fixpack/5402/xml/version.dtd $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd >> $WC_FP5402_DIR/$LOGFILENAME 2>&1

cd $WC_HOME/bin
$ECHO "Running CMRedeploy.sh to update default.xml for Pro Edition"
$ECHO "Running CMRedeploy.sh to update default.xml for Pro Edition" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
./CMRedeploy.sh -updateDefaultXML $WC_HOME/instances/default/xml/default.Pro.xml >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
$ECHO "Running CMRedeploy.sh to update instance_name.xml for Pro Edition"
$ECHO "Running CMRedeploy.sh to update instance_name.xml for Pro Edition" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
./CMRedeploy.sh -updateInstanceXML $WC_HOME/instances/default/xml/UpdateInstance.xml >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cd $CURR_DIR
fi

if [ $WC_EDITION = "Business" ]; then
$ECHO "main - Business Edition"
$ECHO "copying Business Edition files" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
$ECHO "cp $WC_HOME/service/fixpack/5402/36042/advanced/web/tools/adminconsole/UserAdminList.jsp $WC_HOME/wc.ear/wctools.war/tools/adminconsole/UserAdminList.jsp" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp $WC_HOME/service/fixpack/5402/36042/advanced/web/tools/adminconsole/UserAdminList.jsp $WC_HOME/wc.ear/wctools.war/tools/adminconsole/UserAdminList.jsp >> $WC_FP5402_DIR/$LOGFILENAME 2>&1

$ECHO "cp $WC_FP5402_DIR/xml/version.Business.xml $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp $WC_FP5402_DIR/xml/version.Business.xml $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
$ECHO "cp $WC_FP5402_DIR/xml/version.dtd $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp $WC_FP5402_DIR/xml/version.dtd $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd >> $WC_FP5402_DIR/$LOGFILENAME 2>&1

cd $WC_HOME/bin
$ECHO "Running CMRedeploy.sh to update default.xml for Business Edition"
$ECHO "Running CMRedeploy.sh to update default.xml for Business Edition" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
./CMRedeploy.sh -updateDefaultXML $WC_HOME/instances/default/xml/default.Business.xml >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
$ECHO "Running CMRedeploy.sh to update instance_name.xml for Business Edition"
$ECHO "Running CMRedeploy.sh to update instance_name.xml for Business Edition" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
./CMRedeploy.sh -updateInstanceXML $WC_HOME/instances/default/xml/UpdateInstance.xml >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cd $CURR_DIR
fi
}

# make service directories
make_service_dir() {

   if [ -d $WC_SERVICE_DIR ]; then
   	if [ -d $WC_FIXPACK_DIR ]; then
	   if [ -d $WC_FP5402_DIR ]; then
	      return
	   else
	      mkdir $WC_FP5402_DIR
	   fi
	else
	   mkdir $WC_FIXPACK_DIR
	   mkdir $WC_FP5402_DIR
	fi
   else
      mkdir $WC_SERVICE_DIR
      mkdir $WC_FIXPACK_DIR
      mkdir $WC_FP5402_DIR
   fi
}

copy_uninstall_file() {
$ECHO "Copying uninstall script to service directory"
$ECHO "Copying uninstall script to service directory" >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp ./uninstall_was.sh $WC_HOME/service/fixpack/5402 >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
chmod 750 $WC_HOME/service/fixpack/5402/uninstall_was.sh >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
cp ./uninstall_wc.sh $WC_HOME/service/fixpack/5402 >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
chmod 750 $WC_HOME/service/fixpack/5402/uninstall_wc.sh >> $WC_FP5402_DIR/$LOGFILENAME 2>&1
}


# beginning of script.
#clear

TRUE=0
FALSE=1

#ensure correct number of arguments provided.
if [ $# -ne 3 ]; then
   print_usage
   exit 0
else
   WC_HOME=$1
   WAS_HOME=$2
   WC_EDITION=$3
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi

JARFILENAME="WCfixpack5402_wc_SUN.jar"
BACKUPJARFILENAME="WCfixpack5402_wc_SUN_backup.jar"
LOGFILENAME="WCfixpack5402_wc_SUN.log"
DELTA_JAR="Delta.jar"

WC_SERVICE_DIR="$WC_HOME/service"
WC_FIXPACK_DIR="$WC_HOME/service/fixpack"
WC_FP5402_DIR="$WC_HOME/service/fixpack/5402"


# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi


# make service directories
make_service_dir
$ECHO "main - service directories exist/created."

$ECHO "main - Checking Edition"
check_edition

# Install WebSphere Commerce 5.4.0.2 Fixpack, SUN
$ECHO "main - Installing Fixpack."

$WAS_HOME/java/jre/bin/java -jar $JARFILENAME -TargetDir $WC_HOME -backupJar $WC_FP5402_DIR/$BACKUPJARFILENAME -log $WC_FP5402_DIR/$LOGFILENAME

status=$?

if [ $status = 8 ]; then
   $ECHO "exiting install due to user intervention"
   exit 0
fi

$ECHO "main - Copy Edition files"
copy_edition_files

$ECHO "main - Copy uninstall file"
copy_uninstall_file

$ECHO "main - installing fixpack complete."
$ECHO "Please review the installation guide for any additional instructions."

exit 0
