#!/bin/ksh

ECHO="/bin/echo"

$ECHO "  "
$ECHO "Uninstall Fixpack 5.4.0.2 for WebSphere Commerce Suite, SUN"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "  "

# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <was_home> <wc_application_home>"
   $ECHO "Example: ./uninstall_was.sh /opt/WebSphere/AppServer WC_Enterprise_App_[instance].ear"
}


# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WAS_HOME ] && val=2 && \
      [ -d $WAS_HOME/installedApps/$WC_APPLICATION_HOME ]
   then
#   	$ECHO "---- Components path check passed -----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "Invalid WAS_HOME directory."
	      ;;
	   2) $ECHO "Invalid WC_APPLICATION_HOME directory."
	      ;;
	esac
   fi

   return $FALSE
}


# checks if required files exist.
check_files() {
local val=1

   if [ -f $BACKUPJARFILENAME ] && val=2 && \
      [ -f $WAS_HOME/properties/com/ibm/websphere/product.xml ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $BACKUPJARFILENAME"
	      ;;
           2) $ECHO "The following file does not exist: $WAS_HOME/properties/com/ibm/websphere/product.xml"
              ;;
	esac
   fi

   return $FALSE;
}

# Check for Enhancement Pack entry
check_for_enhancementpack() {

   if [`grep EnhancementPack $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.xml` == ``]
   then
      return $TRUE;
   else
      $ECHO "Please un-install Enhancement Pack before un-installing 5.4.0.2 FixPack."
   fi

   return $FALSE;
}

# beginning of script.
#clear

TRUE=0
FALSE=1

#ensure correct number of arguments provided.
if [ $# -ne 2 ]; then
   print_usage
   exit 0
else
   WAS_HOME=$1
   WC_APPLICATION_HOME=$2
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi

BACKUPJARFILENAME="$WC_APPLICATION_HOME"_backup.jar
UNINSTALLLOGFILENAME=uninstall"$WC_APPLICATION_HOME".log

# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi

# check for Enhancement Pack
if check_for_enhancementpack; then
   $ECHO "main - check for Enhancement Pack PASSED."
else
   $ECHO "main - check for Enhancement Pack FAILED."
   exit 0
fi

# Uninstall Fixpack 5.4.0.2 for WebSphere Commerce Suite, SUN
$ECHO "main - uninstalling fixpack."

$WAS_HOME/java/jre/bin/java -jar $BACKUPJARFILENAME -log $UNINSTALLLOGFILENAME 

$ECHO "Removing $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.xml"
$ECHO "Removing $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.xml" >> $UNINSTALLLOGFILENAME 2>&1
rm $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.xml
$ECHO "Removing $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.dtd"
$ECHO "Removing $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.dtd" >> $UNINSTALLLOGFILENAME 2>&1
rm $WAS_HOME/installedApps/$WC_APPLICATION_HOME/properties/com/ibm/commerce/version.dtd

$ECHO "main - uninstalling fixpack complete."

exit 0
