#!/bin/ksh

ECHO="/bin/echo"

$ECHO "  "
$ECHO "Uninstall Fixpack 5.4.0.2 for WebSphere Commerce Suite, SUN"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "  "

# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <wc_home> <was_home>"
   $ECHO "Example: ./uninstall_wc.sh /opt/WebSphere/CommerceServer /opt/WebSphere/AppServer"
}


# Check if required directories exist.
check_paths() {
local val=1

   if [ -d $WC_HOME ] && val=2 && [ -d $WAS_HOME ]
   then
#       $ECHO "---- Components path check passed -----"
        return $TRUE
   else
        $ECHO "---- Please correct following error: ----"

        case $val in
           1) $ECHO "Invalid WC_HOME directory."
              ;;
           2) $ECHO "Invalid WAS_HOME directory."
              ;;
        esac
   fi

   return $FALSE
}

# checks if required files exist.
check_files() {
local val=1

   if [ -f $BACKUPJARFILENAME ] && val=2 && \
      [ -f $WAS_HOME/properties/com/ibm/websphere/product.xml ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $BACKUPJARFILENAME"
	      ;;
           2) $ECHO "The following file does not exist: $WAS_HOME/properties/com/ibm/websphere/product.xml"
              ;;
	esac
   fi

   return $FALSE;
}

# Check for Enhancement Pack entry
check_for_enhancementpack() {

   if [`grep EnhancementPack $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml` == ``]
   then
      return $TRUE;
   else
      $ECHO "Please un-install Enhancement Pack before un-installing 5.4.0.2 FixPack."
   fi

   return $FALSE;

}


# beginning of script.
#clear

TRUE=0
FALSE=1

#ensure correct number of arguments provided.
if [ $# -ne 2 ]; then
   print_usage
   exit 0
else
   WC_HOME=$1
   WAS_HOME=$2
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi

BACKUPJARFILENAME="WCfixpack5402_wc_SUN_backup.jar"
UNINSTALLLOGFILENAME="uninstallWCfixpack5402_wc_SUN.log"


# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi

# check for Enhancement Pack
if check_for_enhancementpack; then
   $ECHO "main - check for Enhancement Pack PASSED."
else
   $ECHO "main - check for Enhancement Pack FAILED."
   exit 0
fi

# Uninstall Fixpack 5.4.0.2 for WebSphere Commerce Suite, SUN
$ECHO "main - uninstalling fixpack."

$ECHO "Running CMRedeploy.sh to remove instance_name.xml entries."
CURR_DIR=$PWD
cd $WC_HOME/bin
$ECHO "Running CMRedeploy.sh to remove instance_name.xml entries" >> $UNINSTALLLOGFILENAME 2>&1
$ECHO "CMRedeploy.sh -updateInstanceXML $WC_HOME/instances/default/xml/RemoveUpdateInstance.xml"
./CMRedeploy.sh -updateInstanceXML $WC_HOME/instances/default/xml/RemoveUpdateInstance.xml >> $UNINSTALLLOGFILENAME 2>&1
cd $CURR_DIR

$WAS_HOME/java/jre/bin/java -jar $BACKUPJARFILENAME -log $UNINSTALLLOGFILENAME

$ECHO "Removing $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml"
$ECHO "Removing $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml" >> $UNINSTALLLOGFILENAME 2>&1
rm $WC_HOME/wc.ear/properties/com/ibm/commerce/version.xml
$ECHO "Removing $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd"
$ECHO "Removing $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd" >> $UNINSTALLLOGFILENAME 2>&1
rm $WC_HOME/wc.ear/properties/com/ibm/commerce/version.dtd

$ECHO "main - uninstalling fixpack complete."

exit 0
